@@ -36,6 +36,10 @@ apriori <-  function(data, parameter = NULL, appearance = NULL, control = NULL)
         data@itemInfo,
         PACKAGE = "arules")                  
 
+    ## so quality knows the transaction size (to calculate absolute 
+    ## counts from support)
+    attr(result@quality, "size.data") <- length(data)
+
     if (is(result, "rules"))  { 
       ## validate sparse Matrix (this takes care of sorting vector i)
       validObject(result@lhs@data)
