@@ -162,7 +162,8 @@ static RULESET *ruleset = NULL; /* ruleset */
   Modification of tract.c
 ----------------------------------------------------------------------*/
 
-static int get_item (ITEMSET *iset, char *x)
+/* static int get_item (ITEMSET *iset, char *x) */
+static int get_item (ITEMSET *iset, const char *x)
 {                               /* --- read an item */
   int  d = 0;                       /* delimiter type */
   ITEM *item;                   /* pointer to item */
@@ -301,7 +302,9 @@ int is_read_in (ITEMSET *iset, INPUT *in)
   iset->cnt = 0;                /* initialize the item counter */
   if (in->index >= in->tnb) return 1;
   for (i = in->ind[in->index]; i < in->ind[in->index+1]; i++) {
-	  d = get_item(iset, CHAR(CHARACTER_POINTER(in->x)[i]));
+	  d = get_item(iset, CHAR(STRING_ELT(in->x, i)));
+	  /* d = get_item(iset, (char*) CHAR(STRING_ELT(in->x, i))); */
+	  /*d = get_item(iset, CHAR(CHARACTER_POINTER(in->x)[i]));*/
   }
   in->index++;
       
@@ -320,12 +323,13 @@ int is_readapp_R (ITEMSET *iset, SEXP app)
 {                               /* --- read appearance indicators */
   int  i, j, h;                       /* delimiter type */
   ITEM *item;                   /* to access the item data */
-  char *def;
+  const char *def;
   int *set;
   SEXP items;
 
   assert(iset && app);         /* check the function arguments */
-  def = CHAR(CHARACTER_POINTER(GET_SLOT(app, install("default")))[0]);
+  def = CHAR(STRING_ELT(GET_SLOT(app, install("default")), 0));
+  /*def = CHAR(CHARACTER_POINTER(GET_SLOT(app, install("default")))[0]);*/
   set = INTEGER(GET_SLOT(app, install("set")));
   items = PROTECT(AS_CHARACTER(GET_SLOT(app, install("items"))));
   
@@ -334,7 +338,8 @@ int is_readapp_R (ITEMSET *iset, SEXP app)
   h = 0;
   for (i = 0; i < 5; i++) {
 	  for (j = 0; j < set[i]; j++) {
-		  item = nim_add(iset->nimap, CHAR(CHARACTER_POINTER(items)[h]), sizeof(ITEM));
+		  item = nim_add(iset->nimap, CHAR(STRING_ELT(items, h)), sizeof(ITEM));
+		  /*item = nim_add(iset->nimap, CHAR(CHARACTER_POINTER(items)[h]), sizeof(ITEM));*/
 		  if (item == EXISTS) return E_DUPITEM;  /* add the new item */
 		  if (item == NULL)   return E_NOMEM;    /* to the name/id map */
 		  item->frq = 0;              /* clear the frequency counters */
@@ -896,7 +901,7 @@ SEXP rapriori(SEXP x, SEXP y, SEXP dim, SEXP parms, SEXP control, SEXP app, SEXP
  	ARparameter param;
  	int k;
 	int load, maxlen;
-	char *target, *arem;
+	const char *target, *arem;
 	clock_t t;
 	INPUT in;
 	SEXP ans;
@@ -915,10 +920,12 @@ SEXP rapriori(SEXP x, SEXP y, SEXP dim, SEXP parms, SEXP control, SEXP app, SEXP
 	param.filter = *REAL(GET_SLOT(control, install("filter")));    /* item usage filtering parameter 'u'*/
 	param.smax = *REAL(GET_SLOT(parms, install("smax")));          /* maximal support    'S' */
 	/* target type (sets/rules/h.edges) 't'*/  
-	target = CHAR(CHARACTER_POINTER(GET_SLOT(parms, install("target")))[0]);
+	target = CHAR(STRING_ELT(GET_SLOT(parms, install("target")), 0)); 
+	/*target = CHAR(CHARACTER_POINTER(GET_SLOT(parms, install("target")))[0]);*/
 	param.target = targetcode(target);
 	/* additional rule evaluation measure 'e'*/  
-	arem = CHAR(CHARACTER_POINTER(GET_SLOT(parms, install("arem")))[0]);
+	arem = CHAR(STRING_ELT(GET_SLOT(parms, install("arem")), 0)); 
+	/*arem = CHAR(CHARACTER_POINTER(GET_SLOT(parms, install("arem")))[0]);*/
 	param.arem = aremcode(arem);
 
 	param.minlen = *INTEGER(GET_SLOT(parms, install("minlen")));   /* minimal rule length 'm'*/
